%global uid 47
%global username ladvd
%global homedir %{_localstatedir}/run/%{name}
%global gecos CDP/LLDP sender for UNIX

%define selinux_variants mls strict targeted
%define modulename ladvd

Name:           ladvd
Version:        1.0.4
Release:        11%{?dist}
Summary:        CDP/LLDP sender for UNIX

Group:          Applications/Internet
License:        ISC
URL:            http://www.blinkenlights.nl/software/ladvd/
Source0:        http://www.blinkenlights.nl/software/ladvd/ladvd-%{version}.tar.gz
Source1:        ladvd.service
Source2:        ladvd.tmpfiles
Source3:        %{modulename}.te
Source4:        %{modulename}.fc
Source5:        %{modulename}.if

BuildRequires:  libevent-devel
BuildRequires:  libcap-ng-devel
BuildRequires:  libpcap-devel
BuildRequires:  m4
BuildRequires:  pkgconfig
BuildRequires:  systemd

%bcond_without  fedora
Requires(pre):  shadow-utils

Provides:       group(%username) = %uid
Provides:       user(%username)  = %uid

%{?systemd_requires}

%description 
ladvd uses CDP / LLDP frames to inform switches about connected hosts, which
simplifies Ethernet switch management. Every 30 seconds it will transmit CDP/
LLDP packets reflecting the current system state. Interfaces (bridge, bonding,
wireless), capabilities (bridging, forwarding, wireless) and addresses (IPv4,
IPv6) are detected dynamically.


%package selinux
Summary:        SELinux policy module supporting %{name}
Group:          System Environment/Base
BuildRequires:  checkpolicy, selinux-policy-devel, hardlink
%if "%{_selinux_policy_version}" != ""
Requires:       selinux-policy >= %{_selinux_policy_version}
%endif
Requires:       %{name} = %{version}-%{release}
Requires(post):   /usr/sbin/semodule, /sbin/restorecon
Requires(postun): /usr/sbin/semodule, /sbin/restorecon


%description selinux
SELinux policy module supporting %{name}


%prep
%setup -q
mkdir SELinux
cp -p %{SOURCE3} %{SOURCE4} %{SOURCE5} SELinux

%build
%configure \
        --with-user=%username \
        --with-pid-dir=%{_localstatedir}/run
make %{?_smp_mflags}

cd SELinux
for selinuxvariant in %{selinux_variants}
do
make NAME=${selinuxvariant} -f /usr/share/selinux/devel/Makefile
mv %{modulename}.pp %{modulename}.pp.${selinuxvariant}
make NAME=${selinuxvariant} -f /usr/share/selinux/devel/Makefile clean
done
cd -


%install
rm -rf %{buildroot}
make install DESTDIR=%{buildroot}
rm -rf %{buildroot}%{_docdir}/ladvd
mkdir -p %{buildroot}%{homedir}
mkdir -p %{buildroot}%{_tmpfilesdir}
install -m 0644 %{SOURCE2} %{buildroot}%{_tmpfilesdir}/%{name}.conf
mkdir -p %{buildroot}%{_unitdir}
cp -p %SOURCE1 %{buildroot}%{_unitdir}


cd SELinux
for selinuxvariant in %{selinux_variants}
do
install -d %{buildroot}%{_datadir}/selinux/${selinuxvariant}
install -p -m 644 %{modulename}.pp.${selinuxvariant} \
%{buildroot}%{_datadir}/selinux/${selinuxvariant}/%{modulename}.pp
done
cd -

/usr/sbin/hardlink -cv %{buildroot}%{_datadir}/selinux


%clean
rm -rf %{buildroot}


%pre
getent group %{username} >/dev/null || groupadd -r %{username} -g %{uid}
getent passwd %{username} >/dev/null || \
    useradd -r -g %{username} -d %{homedir} -s /sbin/nologin -u %{uid} \
    -c '%{gecos}' %{username}
exit 0


%post
%tmpfiles_create %{name}.conf
%systemd_post %{name}.service

%preun
%systemd_preun %{name}.service

%postun
%systemd_postun_with_restart %{name}.service

%post selinux
for selinuxvariant in %{selinux_variants}
do
/usr/sbin/semodule -s ${selinuxvariant} -i \
%{_datadir}/selinux/${selinuxvariant}/%{modulename}.pp &> /dev/null || :
done

%postun selinux
if [ $1 -eq 0 ] ; then
for selinuxvariant in %{selinux_variants}
do
/usr/sbin/semodule -s ${selinuxvariant} -r %{modulename} &> /dev/null || :
done
fi

%triggerun -- ladvd < 0.9.2-2
if /sbin/chkconfig --level 3 ladvd ; then
        /bin/systemctl enable ladvd.service >/dev/null 2>&1 || :
fi


%files
%defattr(-,root,root,-)
%doc doc/ChangeLog doc/README doc/LICENSE doc/TODO
%{_sbindir}/%{name}
%{_sbindir}/%{name}c
%{_mandir}/man8/%{name}.8*
%{_mandir}/man8/%{name}c.8*
%ghost %attr(0755,root,root) %dir %{_localstatedir}/run/%{name}
%{_tmpfilesdir}/%{name}.conf
%{_unitdir}/%{name}.service


%files selinux
%defattr(-,root,root,0755)
%doc SELinux/*
%{_datadir}/selinux/*/%{modulename}.pp


%changelog
* Mon Oct 14 2013 Tomasz Torcz <ttorcz@fedoraproject.org> - 1.0.4-11
- further SELinux policy fixes (#1018493, #1018497, #1018502, #1018503, #1018504, #1018505, #1018506)

* Tue Sep 17 2013 Tomasz Torcz <ttorcz@fedoraproject.org> - 1.0.4-10
- use macro for determining SELinux policy version

* Tue Sep 17 2013 Tomasz Torcz <ttorcz@fedoraproject.org> - 1.0.4-9
- apply SELinux policy patch by Daniel J Walsh (#975959)

* Mon Aug 19 2013 Ralf Corsépius <corsepiu@fedoraproject.org> - 1.0.4-8
- Address FTBFS, RHBZ#992031:
  - Fix typo in spec (Use %%_tmpfilesdir instead of ${_tmpfilesdir}).
  - Use %%{?systemd_requires} instead of %%{systemd_requires}.

* Mon Aug 05 2013 Tomasz Torcz <ttorcz@fedoraproject.org> - 1.0.4-7
- add BR: systemd, as it not longer pulled by default
  (https://lists.fedoraproject.org/pipermail/devel/2013-August/187299.html)

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.4-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Tue Jul 30 2013 Tomasz Torcz <ttorcz@fedoraproject.org> - 1.0.4-5
- remove unnecessary parts for -selinux posts
- selinux policy: allow /etc/passwd read to find out about unpriviledged user (#975959)
- modernize tmpfiles snippets

* Wed Apr 10 2013 Jon Ciesla <limburgher@gmail.com> - 1.0.4-4
- Migrate from fedora-usermgmt to guideline scriptlets.

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.4-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Mon Nov 12 2012 Tomasz Torcz <ttorcz@fedoraproject.org> - 1.0.4-2
- add m4 to buildreq
- switch to systemd macros
- remove chkconfig from fedora package

* Tue Oct 07 2012 Tomasz Torcz <ttorcz@fedoraproject.org> - 1.0.4-1
- create chroot() dir on package install
- update to vesion 1.0.4

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Tue Feb 09 2012 Tomasz Torcz <ttorcz@fedoraproject.org> - 1.0.2-1
- new upstream version

* Mon Jan 24 2012 Tomasz Torcz <ttorcz@fedoraproject.org> - 1.0.0-1
- version 1.0.0
- spec: 
  - drop patch for GCC issue fixed upstream
  - drop BuildRoot: tag
- unit file: 
  - remove StandardOutput=syslog (it is default now)
  - add "-z" option, to have upstream switch name put in interface's ifAlias

* Mon Aug 15 2011 Tomasz Torcz <ttorcz@fedoraproject.org> - 0.9.2-6
- remove sysconfig mention from unit file

* Sat Aug 13 2011 Tomasz Torcz <ttorcz@fedoraproject.org> - 0.9.2-5
- place tmpfiles.d conf in /usr/lib/tmpfiles.d
- drop SysV init script and sysconfig file

* Fri May 6 2011 Tomasz Torcz <ttorcz@fedoraproject.org> - 0.9.2-4
- Fix systemd-related scriptlets (from Bill Nottingham):

    - since we install a systemd service file, run 'systemctl daemon-reload'
    - chkconfig without a level forwards to systemctl, which is not useful for
      SysV migrations. Pass an explicit level.

* Sun Feb 13 2011 Tomasz Torcz <ttorcz@fedoraproject.org> - 0.9.2-3
- fix FTBFS caused by -Werror=unused-but-set-variable 

* Sun Feb 13 2011 Tomasz Torcz <ttorcz@fedoraproject.org> - 0.9.2-2
- provide systemd and tmpfiles integration bits

* Sun Feb 13 2011 Tomasz Torcz <ttorcz@fedoraproject.org> - 0.9.2-1
- new upstream version 0.9.2
- package ladvdc - client command
- simplify initscript, rely on protocol autodetection like upstream suggests
- move homedir to /var/run/ladvd

* Mon Feb 07 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Aug 26 2009 Andreas Thienemann <andreas@bawue.net> - 0.8-1
- Rebase to new upstream release

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sat Oct 18 2008 Andreas Thienemann <andreas@bawue.net> 0.6.1-2
- Added SElinux support package
- Added patch to make it build on EL-4
- Added separate ladvd user

* Sat Oct 18 2008 Andreas Thienemann <andreas@bawue.net> 0.6.1-1
- Initial package
